@@ -5,9 +5,9 @@ from .models import Event
 class FutureEventsViewset(LDPViewSet):
     model = Event
     def get_queryset(self):
-        return super().get_queryset().filter(startDate__gte=datetime.now())
+        return super().get_queryset().filter(endDate__gte=datetime.now())
 
 class PastEventsViewset(LDPViewSet):
     model = Event
     def get_queryset(self):
-        return super().get_queryset().filter(startDate__lt=datetime.now())
+        return super().get_queryset().filter(endDate__lt=datetime.now())
